const RECORD_BODY = "body:";

/*
 * スレッドのディレクトリ名からタイトルを取得します。
 *
 * @param dirName
 * @return
 */
function decodeTitle(dirName) {
	var title = null;
	var temp = dirName.split("_");
	
	if(temp.length < 2)
		return title;
	
	var utf8code = "";
	
	for(var i = 0; i < temp[1].length; i += 2) {
		utf8code += "%" + temp[1].charAt(i) + temp[1].charAt(i + 1);
	}
	
	title = utf8to16( unescape(utf8code) );
	
	return title;
}

/*
 * タイトルからディレクトリ名を取得します。
 *
 * @param title
 * @return
 */
function encodeTitle(title) {
	var utf8title = utf16to8(title);
	
	var dirName = "thread_";
	
	for(var i = 0; i < utf8title.length; i++) {
		var code = utf8title.charCodeAt(i);
		dirName += code.toString(16).toUpperCase();
	}
	
	return dirName;
}

/*
 * 指定スレッドがキャッシュとして存在しているかどうかチェックします。
 *
 * @param thinfo
 * @return bool値
 */
function existCache(thinfo) {
	var exist = false;
	var cachedir = getCacheRootFile();
	
	if(!cachedir || !cachedir.exist())
		return exist;
	
	//var join = cachedir.match(/\/$/) ? "" : "/";
	//var threaddir = cachedir + join + thinfo.file;
	var target = new File(cachedir, thinfo.file);
	exist = target.exist();
	
	return exist;
}

/**
 * 
 */
function getCacheRootFile() {
	var cacheRootFile = null;
	
	var cachedir = getPref("moonfox.cachedir");
	
	try {
		if(cachedir && cachedir != "")
			cacheRootFile = new File(cachedir);
	} catch(e) {
		throw e;
	}
	
	return cacheRootFile;
}

/*
 * スレッド一覧をCacheFileオブジェクトの配列にして返します。
 *
 * @return
 */
function getThreadCacheFileList() {
	var cacheFileList = new Array();
	
	var fileList = getThreadFileList();
	
	for(var i = 0; i < fileList.length; i++) {
		var cacheFile = new CacheFile(fileList[i]);
		cacheFileList.push(cacheFile);
	}
	
	return cacheFileList;
}

/*
 *
 *
 *
 */
function getThreadFile(dirName) {
	var file = null;

	var cachedir = getCacheRootFile();
	
	if(!cachedir || !cachedir.exist())
		return file;
	
	//var join = cachedir.match(/\/$/) ? "" : "/";
	//var path = cachedir + join + dirName;
	file = new File(cachedir, dirName);
	
	return file;
}

/*
 * スレッド一覧をFileオブジェクトの配列にして返します。
 *
 * @return
 */
function getThreadFileList() {
	var list = new Array();
	
	var cachedir = getCacheRootFile();
	
	if(!cachedir || !cachedir.exist())
		return list;
	
	if(cachedir.exist())
		list = cachedir.listFile();
	
	return list;
}

/**
 *
 *
 * @param file
 */
function parseRecord(file, threadName) {
	var record = new Record(threadName);
	
	var is = file.establishConverterInputStream("UTF-8");
	
	var strbuf = {};
	var readStr = "";
	
	var size = file.size();
	
	if(size < 1024 * 50) {
		while( is.readString(size, strbuf) != 0 ) {
			readStr += strbuf.value;
			strbuf = {};
		}
	} else {
		//ファイルサイズが50kbを超える時は途中スキップする
		var len = 0;
		var readCnt = is.readString(1024, strbuf);
		len += readCnt;
		var skip = false;
		while(readCnt > 0) {
			if(!skip)
				readStr += strbuf.value;
			
			if(readStr.indexOf("<>attach:") >= 0 && len < size - 4096) {
				skip = true;
			}
			
			strbuf = {};
			readCnt = is.readString(1024, strbuf);
			len += readCnt;
			
			if(len >= size - 4096)
				skip = false;
		}
	}
	
	is.close();
	
	var list = readStr.split("<>");
	
	if(list.length >= 2) {
		
		record.setId(list[0], list[1]);
		
		for(var i = 2; i < list.length; i++) {
			if(!list[i])
				break;
			
			if( list[i].match(/^body:(.+)/) ) {
				record.body = RegExp.$1;
			} else if( list[i].match(/^attach:/) ) {
				record.attach = 1;
			} else if( list[i].match(/^name:(.+)/) ) {
				record.name = RegExp.$1;
			} else if( list[i].match(/^mail:(.+)/) ) {
				record.mail = RegExp.$1;
			} else if( list[i].match(/^pubkey:(.+)/) ) {
				record.pubkey = RegExp.$1;
			} else if( list[i].match(/^sign:(.+)/) ) {
				record.sign = RegExp.$1;
			} else if( list[i].match(/^target:(.+)/) ) {
				record.target = RegExp.$1;
			} else if( list[i].match(/^suffix:(.+)/) ) {
				record.suffix = RegExp.$1;
			} else if( list[i].match(/^remove_id:(.+)/) ) {
				record.removeHash = RegExp.$1;
			} else if( list[i].match(/^remove_stamp:(.+)/) ) {
				record.removeStamp = RegExp.$1;
			} 
		}
	}
	
	return record;
}